==> mingw-w64-clang-aarch64-geographiclib-1.52-2-any.pkg.tar.zst: clangarm64/share/doc/GeographicLib/html/hierarchy.js <==
var hierarchy =
[
    [ "GeographicLib::Accumulator< T >", "classGeographicLib_1_1Accumulator.html", null ],
    [ "GeographicLib::AlbersEqualArea", "classGeographicLib_1_1AlbersEqualArea.html", null ],
    [ "GeographicLib::AzimuthalEquidistant", "classGeographicLib_1_1AzimuthalEquidistant.html", null ],
    [ "GeographicLib::CassiniSoldner", "classGeographicLib_1_1CassiniSoldner.html", null ],
    [ "GeographicLib::CircularEngine", "classGeographicLib_1_1CircularEngine.html", null ],
    [ "GeographicLib::SphericalEngine::coeff", "classGeographicLib_1_1SphericalEngine_1_1coeff.html", null ],
    [ "GeographicLib::Constants", "classGeographicLib_1_1Constants.html", null ],
    [ "GeographicLib::DMS", "classGeographicLib_1_1DMS.html", null ],
    [ "GeographicLib::Ellipsoid", "classGeographicLib_1_1Ellipsoid.html", null ],
    [ "GeographicLib::EllipticFunction", "classGeographicLib_1_1EllipticFunction.html", null ],
    [ "GeographicLib::GARS", "classGeographicLib_1_1GARS.html", null ],
    [ "GeographicLib::Geocentric", "classGeographicLib_1_1Geocentric.html", null ],
    [ "GeographicLib::GeoCoords", "classGeographicLib_1_1GeoCoords.html", null ],
    [ "GeographicLib::Geodesic", "classGeographicLib_1_1Geodesic.html", null ],
    [ "GeographicLib::GeodesicExact", "classGeographicLib_1_1GeodesicExact.html", null ],
    [ "GeographicLib::GeodesicLine", "classGeographicLib_1_1GeodesicLine.html", null ],
    [ "GeographicLib::GeodesicLineExact", "classGeographicLib_1_1GeodesicLineExact.html", null ],
    [ "GeographicLib::Geohash", "classGeographicLib_1_1Geohash.html", null ],
    [ "GeographicLib::Geoid", "classGeographicLib_1_1Geoid.html", null ],
    [ "GeographicLib::Georef", "classGeographicLib_1_1Georef.html", null ],
    [ "GeographicLib::Gnomonic", "classGeographicLib_1_1Gnomonic.html", null ],
    [ "GeographicLib::GravityCircle", "classGeographicLib_1_1GravityCircle.html", null ],
    [ "GeographicLib::GravityModel", "classGeographicLib_1_1GravityModel.html", null ],
    [ "GeographicLib::JacobiConformal", "classGeographicLib_1_1JacobiConformal.html", null ],
    [ "GeographicLib::LambertConformalConic", "classGeographicLib_1_1LambertConformalConic.html", null ],
    [ "GeographicLib::LocalCartesian", "classGeographicLib_1_1LocalCartesian.html", null ],
    [ "GeographicLib::MagneticCircle", "classGeographicLib_1_1MagneticCircle.html", null ],
    [ "GeographicLib::MagneticModel", "classGeographicLib_1_1MagneticModel.html", null ],
    [ "GeographicLib::Math", "classGeographicLib_1_1Math.html", null ],
    [ "GeographicLib::MGRS", "classGeographicLib_1_1MGRS.html", null ],
    [ "GeographicLib::NearestNeighbor< dist_t, pos_t, distfun_t >", "classGeographicLib_1_1NearestNeighbor.html", null ],
    [ "GeographicLib::NormalGravity", "classGeographicLib_1_1NormalGravity.html", null ],
    [ "GeographicLib::OSGB", "classGeographicLib_1_1OSGB.html", null ],
    [ "GeographicLib::PolarStereographic", "classGeographicLib_1_1PolarStereographic.html", null ],
    [ "GeographicLib::PolygonAreaT< GeodType >", "classGeographicLib_1_1PolygonAreaT.html", null ],
    [ "GeographicLib::Rhumb", "classGeographicLib_1_1Rhumb.html", null ],
    [ "GeographicLib::RhumbLine", "classGeographicLib_1_1RhumbLine.html", null ],
    [ "std::runtime_error", null, [
      [ "GeographicLib::GeographicErr", "classGeographicLib_1_1GeographicErr.html", null ]
    ] ],
    [ "GeographicLib::SphericalEngine", "classGeographicLib_1_1SphericalEngine.html", null ],
    [ "GeographicLib::SphericalHarmonic", "classGeographicLib_1_1SphericalHarmonic.html", null ],
    [ "GeographicLib::SphericalHarmonic1", "classGeographicLib_1_1SphericalHarmonic1.html", null ],
    [ "GeographicLib::SphericalHarmonic2", "classGeographicLib_1_1SphericalHarmonic2.html", null ],
    [ "GeographicLib::TransverseMercator", "classGeographicLib_1_1TransverseMercator.html", null ],
    [ "GeographicLib::TransverseMercatorExact", "classGeographicLib_1_1TransverseMercatorExact.html", null ],
    [ "GeographicLib::Utility", "classGeographicLib_1_1Utility.html", null ],
    [ "GeographicLib::UTMUPS", "classGeographicLib_1_1UTMUPS.html", null ]
];

==> mingw-w64-clang-aarch64-geographiclib-2.7-1-any.pkg.tar.zst: clangarm64/share/doc/GeographicLib/html/hierarchy.js <==
var hierarchy =
[
    [ "GeographicLib::Accumulator&lt; T &gt;", "classGeographicLib_1_1Accumulator.html", null ],
    [ "GeographicLib::AlbersEqualArea", "classGeographicLib_1_1AlbersEqualArea.html", null ],
    [ "GeographicLib::AngleT&lt; T &gt;", "classGeographicLib_1_1AngleT.html", null ],
    [ "GeographicLib::AuxAngle", "classGeographicLib_1_1AuxAngle.html", null ],
    [ "GeographicLib::AuxLatitude", "classGeographicLib_1_1AuxLatitude.html", [
      [ "GeographicLib::DAuxLatitude", "classGeographicLib_1_1DAuxLatitude.html", null ]
    ] ],
    [ "GeographicLib::AzimuthalEquidistant", "classGeographicLib_1_1AzimuthalEquidistant.html", null ],
    [ "GeographicLib::Triaxial::Cartesian3", "classGeographicLib_1_1Triaxial_1_1Cartesian3.html", null ],
    [ "GeographicLib::CassiniSoldner", "classGeographicLib_1_1CassiniSoldner.html", null ],
    [ "GeographicLib::CircularEngine", "classGeographicLib_1_1CircularEngine.html", null ],
    [ "GeographicLib::SphericalEngine::coeff", "classGeographicLib_1_1SphericalEngine_1_1coeff.html", null ],
    [ "GeographicLib::Triaxial::Conformal3", "classGeographicLib_1_1Triaxial_1_1Conformal3.html", null ],
    [ "GeographicLib::Constants", "classGeographicLib_1_1Constants.html", null ],
    [ "GeographicLib::Triaxial::GeodesicLine3::fline::disttx", "classGeographicLib_1_1Triaxial_1_1GeodesicLine3_1_1fline_1_1disttx.html", null ],
    [ "GeographicLib::DMS", "classGeographicLib_1_1DMS.html", null ],
    [ "GeographicLib::DST", "classGeographicLib_1_1DST.html", null ],
    [ "GeographicLib::Ellipsoid", "classGeographicLib_1_1Ellipsoid.html", null ],
    [ "GeographicLib::Triaxial::Ellipsoid3", "classGeographicLib_1_1Triaxial_1_1Ellipsoid3.html", null ],
    [ "GeographicLib::EllipticFunction", "classGeographicLib_1_1EllipticFunction.html", null ],
    [ "GeographicLib::Triaxial::GeodesicLine3::fline::fics", "classGeographicLib_1_1Triaxial_1_1GeodesicLine3_1_1fline_1_1fics.html", null ],
    [ "GeographicLib::GARS", "classGeographicLib_1_1GARS.html", null ],
    [ "GeographicLib::Geocentric", "classGeographicLib_1_1Geocentric.html", null ],
    [ "GeographicLib::GeoCoords", "classGeographicLib_1_1GeoCoords.html", null ],
    [ "GeographicLib::Geodesic", "classGeographicLib_1_1Geodesic.html", null ],
    [ "GeographicLib::Triaxial::Geodesic3", "classGeographicLib_1_1Triaxial_1_1Geodesic3.html", null ],
    [ "GeographicLib::GeodesicExact", "classGeographicLib_1_1GeodesicExact.html", null ],
    [ "GeographicLib::GeodesicLine", "classGeographicLib_1_1GeodesicLine.html", null ],
    [ "GeographicLib::Triaxial::GeodesicLine3", "classGeographicLib_1_1Triaxial_1_1GeodesicLine3.html", null ],
    [ "GeographicLib::GeodesicLineExact", "classGeographicLib_1_1GeodesicLineExact.html", null ],
    [ "GeographicLib::Geohash", "classGeographicLib_1_1Geohash.html", null ],
    [ "GeographicLib::Geoid", "classGeographicLib_1_1Geoid.html", null ],
    [ "GeographicLib::Georef", "classGeographicLib_1_1Georef.html", null ],
    [ "GeographicLib::Triaxial::GeodesicLine3::gline::gics", "classGeographicLib_1_1Triaxial_1_1GeodesicLine3_1_1gline_1_1gics.html", null ],
    [ "GeographicLib::Gnomonic", "classGeographicLib_1_1Gnomonic.html", null ],
    [ "GeographicLib::GravityCircle", "classGeographicLib_1_1GravityCircle.html", null ],
    [ "GeographicLib::GravityModel", "classGeographicLib_1_1GravityModel.html", null ],
    [ "GeographicLib::Intersect", "classGeographicLib_1_1Intersect.html", null ],
    [ "GeographicLib::LambertConformalConic", "classGeographicLib_1_1LambertConformalConic.html", null ],
    [ "GeographicLib::LocalCartesian", "classGeographicLib_1_1LocalCartesian.html", null ],
    [ "GeographicLib::MagneticCircle", "classGeographicLib_1_1MagneticCircle.html", null ],
    [ "GeographicLib::MagneticModel", "classGeographicLib_1_1MagneticModel.html", null ],
    [ "GeographicLib::Math", "classGeographicLib_1_1Math.html", null ],
    [ "GeographicLib::MGRS", "classGeographicLib_1_1MGRS.html", null ],
    [ "GeographicLib::NearestNeighbor&lt; dist_t, pos_t, distfun_t &gt;", "classGeographicLib_1_1NearestNeighbor.html", null ],
    [ "GeographicLib::NormalGravity", "classGeographicLib_1_1NormalGravity.html", null ],
    [ "GeographicLib::OSGB", "classGeographicLib_1_1OSGB.html", null ],
    [ "GeographicLib::PolarStereographic", "classGeographicLib_1_1PolarStereographic.html", null ],
    [ "GeographicLib::PolygonAreaT&lt; GeodType &gt;", "classGeographicLib_1_1PolygonAreaT.html", null ],
    [ "GeographicLib::Rhumb", "classGeographicLib_1_1Rhumb.html", null ],
    [ "GeographicLib::RhumbLine", "classGeographicLib_1_1RhumbLine.html", null ],
    [ "std::runtime_error", null, [
      [ "GeographicLib::GeographicErr", "classGeographicLib_1_1GeographicErr.html", null ]
    ] ],
    [ "GeographicLib::SphericalEngine", "classGeographicLib_1_1SphericalEngine.html", null ],
    [ "GeographicLib::SphericalHarmonic", "classGeographicLib_1_1SphericalHarmonic.html", null ],
    [ "GeographicLib::SphericalHarmonic1", "classGeographicLib_1_1SphericalHarmonic1.html", null ],
    [ "GeographicLib::SphericalHarmonic2", "classGeographicLib_1_1SphericalHarmonic2.html", null ],
    [ "GeographicLib::TransverseMercator", "classGeographicLib_1_1TransverseMercator.html", null ],
    [ "GeographicLib::TransverseMercatorExact", "classGeographicLib_1_1TransverseMercatorExact.html", null ],
    [ "GeographicLib::experimental::TriaxialGeodesicODE", "classGeographicLib_1_1experimental_1_1TriaxialGeodesicODE.html", null ],
    [ "GeographicLib::Trigfun", "classGeographicLib_1_1Trigfun.html", null ],
    [ "GeographicLib::TrigfunExt", "classGeographicLib_1_1TrigfunExt.html", null ],
    [ "GeographicLib::Utility", "classGeographicLib_1_1Utility.html", null ],
    [ "GeographicLib::UTMUPS", "classGeographicLib_1_1UTMUPS.html", null ]
];
